@@ -47,7 +47,7 @@
  *
  * Since: 1.6
  */
-#define QMI_MINOR_VERSION (28)
+#define QMI_MINOR_VERSION (36)
 
 /**
  * QMI_MICRO_VERSION:
@@ -57,7 +57,7 @@
  *
  * Since: 1.6
  */
-#define QMI_MICRO_VERSION (2)
+#define QMI_MICRO_VERSION (0)
 
 /**
  * QMI_CHECK_VERSION:
@@ -109,6 +109,23 @@
  *
  * Since: 1.26
  */
-#define QMI_QRTR_SUPPORTED 1
+#define QMI_QRTR_SUPPORTED 0
+
+/**
+ * QMI_RMNET_SUPPORTED:
+ *
+ * Symbol to expose wether RMNET link management operations are supported. The
+ * symbol is always defined and set to either or 1 or 0.
+ *
+ * E.g.:
+ * |[
+ *  #if QMI_RMNET_SUPPORTED
+ *      // do something
+ *  #endif
+ * ]|
+ *
+ * Since: 1.30
+ */
+#define QMI_RMNET_SUPPORTED 1
 
 #endif /* _QMI_VERSION_H_ */
